<?php
$modx->addPackage('shopkeeper3', $modx->getOption('core_path') . 'components/shopkeeper3/model/');
//params
$tcsCheque = $modx->getOption('tcsCheque', $scriptProperties, 0);
$tcsFfd12 = $modx->getOption('tcsChequeFfd12', $scriptProperties, 0);
$tcsLanguage = $modx->getOption('tcsLanguage', $scriptProperties, 0);
$tcsTinkoffKey = $modx->getOption('tcsTinkoffKey', $scriptProperties, 0);
$tcsPassword = $modx->getOption('tcsPassword', $scriptProperties, 0);
$tcsEmailCompany = $modx->getOption('tcsEmailCompany', $scriptProperties, 0);
$tcsPaymentMethod = $modx->getOption('tcsPaymentMethod', $scriptProperties, 0);
$tcsPaymentObject = $modx->getOption('tcsPaymentObject', $scriptProperties, 0);
$tcsUrl = 'https://securepay.tinkoff.ru/v2/Init';

$tcsTaxation = $modx->getOption('tcsTaxation', $scriptProperties, 0);
$tcsVat = $modx->getOption('tcsVat', $scriptProperties, 0);
$tcsShippingVat = $modx->getOption('tcsShippingVat', $scriptProperties, 0);

$orderId = $modx->getOption('id', $_SESSION['shk_lastOrder'], null);
$order = $modx->getObject('shk_order', $orderId);

$order_data = array();
$response = $modx->runProcessor('getorder',
    array(
        'order_id' => $orderId,
        'date_format' => 'H:i:s d/m/Y'
    ),
    array('processors_path' => MODX_CORE_PATH . 'components/shopkeeper3/processors/mgr/')
);

if (!$response->isError() && $result = $response->getResponse()) {
    $order_data = $result['object'];
}

$purchases = $order_data['purchases'];
$items = [];

foreach ($purchases as $purchase) {
    $price = round($purchase['price'] * 100);
    $newItem = array(
        'Name' => mb_substr($purchase['name'], 0, 64),
        'Price' => $price,
        'Quantity' => $purchase['count'],
        'Amount' => round($purchase['count'] * $price),
		'PaymentMethod' => trim($tcsPaymentMethod),
		'PaymentObject' => trim($tcsPaymentObject),
        'Tax' => $tcsVat,
    );
    if($tcsFfd12 == 1) {
     $newItem['MeasurementUnit'] = 'pc';
    }
    array_push($items, $newItem);
}

$shipping = array(
    'Name' => mb_substr($order_data['delivery'], 0, 64),
    'Price' => round($order_data['delivery_price'] * 100),
    'Quantity' => 1,
    'Amount' => round($order_data['delivery_price'] * 100),
	'PaymentMethod' => trim($tcsPaymentMethod),
	'PaymentObject' => 'service',
    'Tax' => $tcsShippingVat,
);
if($tcsFfd12 == 1) {
     $shipping['MeasurementUnit'] = 'pc';
    }
if (round($order_data['delivery_price'] * 100) > 0) {
    array_push($items, $shipping);
}


$receipt = array(
    'EmailCompany' => mb_substr($tcsEmailCompany,0 ,64),
    'Email' => $order->get('email'),
    'Taxation' => $tcsTaxation,
    'Items' => $items,
);
if($tcsFfd12 == 1) {
      $receipt['FfdVersion'] = '1.2';
    }

if (($_SESSION['shk_lastOrder']['payment'] != 'tcs') && (!$_GET['ord_id'])) { // Проверяем что у нас способ оплаты указан tcs
    $modx->sendRedirect('/checkout/success.html', 0, 'REDIRECT_HEADER');
}

if (isset($order)) {
    $order_status = $order->get('status');
    $amount = round($order->get('price') * 100);
    $email = $order->get('email');

    $args['OrderId'] = $orderId ?: '';
    $args['Amount'] = $amount ?: '';
    $args['Description'] = "Оплата счета №" . $orderId;
    $args['DATA'] = array(
        'Email' => $email,
        'Connection_type' => 'modx_2.1',
    );
    $args['Receipt'] = $receipt;
    $args['TerminalKey'] = $tcsTinkoffKey;
    $args['Password'] = $tcsPassword;
    $token = '';
    ksort($args);

    foreach ($args as $arg) {
        if(!is_array($arg)) {
            $token .= $arg;
        }
    }

    $token = hash('sha256', $token);
    $args['Token'] = $token;
    unset($args['Password']);

    if ($tcsCheque == 1) {
        if (!$tcsTaxation) {
            return print_r('Не удалось получить данные о системе налогообложения. Проверьте настройки.');
        }
        if (!$tcsVat) {
            return print_r('Не удалось получить данные о налоге на товар. Проверьте настройки.');
        }
        if (!$tcsShippingVat) {
            return print_r('Не удалось получить данные о налоге на доставку. Проверьте настройки.');
        }
    } else {
        unset($args['Receipt']);
    }

    if($tcsLanguage == 'en'){
        $args['Language'] = 'en';
    }

    $args = json_encode($args);

    if ($curl = curl_init()) {
        curl_setopt($curl, CURLOPT_URL, $tcsUrl);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $args);
        curl_setopt($curl, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
        ));
        $out = curl_exec($curl);

        $json = json_decode($out);
        curl_close($curl);

        if ($json->PaymentURL) {
            $change_status = $order->set('status', 2);
            $order->save();
            $modx->invokeEvent('OnSHKChangeStatus', array('order_id' => $orderId, 'status' => 2));
            $modx->sendRedirect($json->PaymentURL);
        }

        return $json->PaymentURL ?: $out;
    } else {
        $modx->sendRedirect('/checkout/error.html', 0, 'REDIRECT_HEADER');
    }
}